@@ -3,16 +3,15 @@
 """
 from __future__ import annotations
 
-import os
 import time
-from pydantic import BaseModel
-from multiprocessing import current_process
+from pathlib import Path
 
+from pydantic import BaseModel
 import xarray as xr
 
 from mfire.settings import Settings, get_logger
-from mfire.utils.xr_utils import ArrayLoader
-from mfire.utils.hash import MD5
+from mfire.utils import MD5, current_process
+from mfire.utils.xr_utils import ArrayLoader, LoaderError
 
 
 # Logging
@@ -36,8 +35,7 @@ class BaseComposite(BaseModel):
     _cached_filenames: dict = dict()
 
     class Config:
-        """ Cette classe Config permet de contrôler de comportement de pydantic
-        """
+        """Cette classe Config permet de contrôler de comportement de pydantic"""
 
         underscore_attrs_are_private = True
         arbitrary_types_allowed = True
@@ -55,7 +53,7 @@ class BaseComposite(BaseModel):
         """
         return f"{self.__class__.__name__}/{self.hash}"
 
-    def cached_filename(self, attr: str = "data") -> str:
+    def cached_filename(self, attr: str = "data") -> Path:
         """Property created to define the filename of the cached file
         and creating the directory if it doesn't exists
 
@@ -63,27 +61,9 @@ class BaseComposite(BaseModel):
             str: self cached file's full name
         """
         if self._cached_filenames.get(attr, None) is None:
-            filebase = os.path.join(
-                Settings().cache_dirname, f"{self.cached_basename}_{attr}"
+            self._cached_filenames[attr] = (
+                Settings().cache_dirname / f"{self.cached_basename}_{attr}"
             )
-            dirname, base = os.path.split(filebase)
-            os.makedirs(dirname, exist_ok=True)
-            # we retrieve all basenames starting with our base in the cache
-            basenames = [
-                f
-                for f in os.listdir(dirname)
-                if (f.startswith(base) and not f.endswith(".tmp"))
-            ]
-            if basenames:
-                # we take the last modified file
-                basename = max(
-                    basenames, key=lambda f: os.path.getmtime(os.path.join(dirname, f))
-                )
-            else:
-                # else we create a new basename
-                tmp_hash = MD5(f"{time.time()}{current_process().name}").hash
-                basename = f"{base}-{tmp_hash}"
-            self._cached_filenames[attr] = os.path.join(dirname, basename)
         return self._cached_filenames[attr]
 
     def is_cached(self) -> bool:
@@ -92,48 +72,51 @@ class BaseComposite(BaseModel):
         Returns:
             bool: Whether the object is cached.
         """
-        return all(
-            os.path.isfile(self.cached_filename(attr)) for attr in self._cached_attrs
-        )
+        return all(self.cached_filename(attr).is_file() for attr in self._cached_attrs)
 
-    def load_cache(self):
+    def load_cache(self) -> bool:
         """Load a given file if a filename is given
         or load a cached file if it exists.
 
-        Args:
-            filename (str, optional): File to open.
-                Defaults to None.
-
         Raises:
-            ValueError: Raised if no filename is given and no file is cached.
+            FileNotFoundError: Raised if no filename is given and no file is cached.
         """
         if not self.is_cached():
-            raise ValueError(f"{self!r} not cached, you must compute it before.")
+            raise FileNotFoundError(f"{self!r} not cached, you must compute it before.")
 
         for attr, loader_class in self._cached_attrs.items():
             filename = self.cached_filename(attr)
-            loader = loader_class(filename=filename)
-            self.__setattr__(f"_{attr}", loader.load())
+            try:
+                loader = loader_class(filename=filename)
+                self.__setattr__(f"_{attr}", loader.load())
+            except (LoaderError, FileNotFoundError) as excpt:
+                LOGGER.warning(f"Exception caught during cache loading : {repr(excpt)}")
+                return False
+        return True
 
     def dump_cache(self):
         """Method for dumping the self._data into a netcdf file.
         If no filename is provided, it is dumped to cache.
-
-        Args:
-            filename (str, optional): File to dump. Defaults to None.
         """
         for attr, loader_class in self._cached_attrs.items():
             filename = self.cached_filename(attr)
-            if not os.path.isfile(filename):
-                tmp_filename = filename + ".tmp"
-                loader = loader_class(filename=tmp_filename)
-                dump_status = loader.dump(data=self.__getattribute__(f"_{attr}"))
+            if not filename.is_file():
+                filename.parent.mkdir(parents=True, exist_ok=True)
+                tmp_hash = MD5(f"{current_process().name}-{time.time()}").hash
+                tmp_filename = Path(f"{filename}{tmp_hash}.tmp")
+                try:
+                    loader = loader_class(filename=tmp_filename)
+                    dump_status = loader.dump(data=self.__getattribute__(f"_{attr}"))
+                    err_msg = ""
+                except LoaderError as excpt:
+                    dump_status = False
+                    err_msg = excpt
                 if dump_status:
-                    os.rename(tmp_filename, filename)
+                    tmp_filename.rename(filename)
                 else:
                     LOGGER.warning(
-                        f"Failed to dump attribute '_{attr}' "
-                        f"to tmp cached file {tmp_filename} using {loader_class}."
+                        f"Failed to dump attribute '_{attr}' to tmp cached file "
+                        f"{tmp_filename} using {loader_class}. {err_msg}"
                     )
 
     def _compute(self, **kwargs) -> xr.DataArray:
@@ -159,9 +142,7 @@ class BaseComposite(BaseModel):
             xr.DataArray: Computed data
         """
         if self._data is None:
-            if self.is_cached():
-                self.load_cache()
-            else:
+            if not (self.is_cached() and self.load_cache()):
                 self._data = self._compute(**kwargs)
                 self.dump_cache()
 
@@ -188,7 +169,7 @@ class BaseComposite(BaseModel):
         """
         if self.is_cached():
             for filename in self._cached_filenames.values():
-                os.remove(filename)
+                filename.unlink()
         self.reset()
 
     @property
